==> inspect-api-0.0.24-20250624.015636-1-sources.jar: com/tll/inspect/rpc/vo/plan/StoreSimpleInfoVO.java <==
package com.tll.inspect.rpc.vo.plan;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * @author: daidemin
 * Date: 2024/11/12 18:24
 */
@Data
@ApiModel("门店简单信息")
public class StoreSimpleInfoVO implements Serializable {

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店编码")
    private String storeCode;

    @ApiModelProperty(value = "法人姓名")
    private String legalPerson;

    @ApiModelProperty(value = "法人电话")
    private String legalPersonPhone;

    @ApiModelProperty(value = "法人身份证号")
    private String legalPersonIdCard;

    @ApiModelProperty(value = "法人联系地址")
    private String legalPersonAddress;

    @ApiModelProperty(value = "房租（万/年）")
    private String rent;

    @ApiModelProperty(value = "区域经理")
    private String areaManager;

    @ApiModelProperty(value = "门店地址")
    private String storeAddress;

    @ApiModelProperty(value = "运营状态：0：签约、1：营业中、2：短期闭店、3：空合同、4：到期解约、5：长期闭店、7：待装修、8：强制解约、9：其它解约")
    private Integer operationStatus;

    @ApiModelProperty(value = "门店类型：1：加盟店  0：直营店")
    private Integer storeType;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "登记人")
    private String registrant;

    @ApiModelProperty(value = "sap编码")
    private String sapCode;

    //todo 封账门店信息 缺少 巡检状态 实际巡检时间
    @ApiModelProperty(value = "巡检状态")
    private String inspectionStatus;
    
    @ApiModelProperty(value = "实际巡检时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime actualInspectionTime;


}

==> inspect-api-0.0.61-20250811.034517-2-sources.jar: com/tll/inspect/rpc/vo/plan/StoreSimpleInfoVO.java <==
package com.tll.inspect.rpc.vo.plan;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * @author: daidemin
 * Date: 2024/11/12 18:24
 */
@Data
@ApiModel("门店简单信息")
public class StoreSimpleInfoVO implements Serializable {

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店编码")
    private String storeCode;

    @ApiModelProperty(value = "法人姓名")
    private String legalPerson;

    @ApiModelProperty(value = "法人电话")
    private String legalPersonPhone;

    @ApiModelProperty(value = "法人身份证号")
    private String legalPersonIdCard;

    @ApiModelProperty(value = "法人联系地址")
    private String legalPersonAddress;

    @ApiModelProperty(value = "房租（万/年）")
    private String rent;

    @ApiModelProperty(value = "区域经理")
    private String areaManager;

    @ApiModelProperty(value = "门店地址")
    private String storeAddress;

    @ApiModelProperty(value = "运营状态：0：签约、1：营业中、2：短期闭店、3：空合同、4：到期解约、5：长期闭店、7：待装修、8：强制解约、9：其它解约")
    private Integer operationStatus;

    @ApiModelProperty(value = "门店类型：1：加盟店  0：直营店")
    private Integer storeType;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "登记人")
    private String registrant;

    @ApiModelProperty(value = "sap编码")
    private String sapCode;

    // 封账门店信息 缺少 巡检状态 实际巡检时间
    @ApiModelProperty(value = "巡检状态: 1:已巡,2:计划中,3:未巡")
    private Integer inspectionStatus=3;
    
    @ApiModelProperty(value = "实际巡检时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime actualInspectionTime;
    
    @ApiModelProperty(value = "冗余字段-巡检中心-行程门店关联表id")
    private Long tllTravelStoreId;

    @ApiModelProperty(value = "冗余字段-行程id")
    private Long travelId;

    @ApiModelProperty(value = "冗余字段-巡检计划id")
    private Long planId;

    @ApiModelProperty(value = "冗余字段-渠道：1-普通门店添加 2-交叉巡检门店添加")
    private Integer channel;
    
    @ApiModelProperty(value = "冗余字段-巡检任务编码")
    private String inspectTaskNumber;
    
    @ApiModelProperty(value = "冗余字段-签到id")
    private Long signInId;

    @ApiModelProperty(value = "冗余字段-签到时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime signInTime;
    
    @ApiModelProperty(value = "冗余字段-交叉巡检id")
    private Long id;


}
